"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Observable {
    constructor(collect_intervall = 100) {
        this.collect_intervall = collect_intervall;
        this.subscriber = [];
        this.subscriberCollect = [];
        this.events = [];
        this.timeout = undefined;
    }
    /**
     * Creates Public API with subscribe and unsubscribe
     *
     * @returns {object}
     */
    getPublicApi() {
        return {
            subscribe: (callback) => {
                let oldcb = this.subscriber.find(e => e === callback);
                if (!oldcb)
                    this.subscriber.push(callback);
            },
            unsubscribe: (callback) => {
                let idx = this.subscriber.findIndex(e => e === callback);
                if (idx >= 0) {
                    this.subscriber.splice(idx, 1);
                }
                else {
                    idx = this.subscriberCollect.findIndex(e => e === callback);
                    if (idx >= 0)
                        this.subscriberCollect.splice(idx, 1);
                }
            },
            subscribeCollect: (callback) => {
                let oldcb = this.subscriberCollect.find(e => e === callback);
                if (!oldcb)
                    this.subscriberCollect.push(callback);
            }
        };
    }
    /**
     * Sends data to all subscribers
     * @param data data to be sent
     */
    send(data) {
        this.subscriber.forEach(e => e(data));
        this.events.push(data);
        if (!this.timeout) {
            this.timeout = setTimeout(() => {
                this.subscriberCollect.forEach(cb => {
                    cb(this.events);
                });
                this.timeout = undefined;
            }, this.collect_intervall);
        }
    }
}
exports.default = Observable;
//# sourceMappingURL=observable.js.map